"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
exports.withAuth = withAuth;

var _server = require("next/server");

var _jwt = require("../jwt");

var _parseUrl = _interopRequireDefault(require("../lib/parse-url"));

async function handleMiddleware(req, options, onSuccess) {
  var _options$pages$signIn, _options$pages, _options$pages$error, _options$pages2, _options$secret, _options$callbacks$au, _options$callbacks;

  const signInPage = (_options$pages$signIn = options === null || options === void 0 ? void 0 : (_options$pages = options.pages) === null || _options$pages === void 0 ? void 0 : _options$pages.signIn) !== null && _options$pages$signIn !== void 0 ? _options$pages$signIn : "/api/auth/signin";
  const errorPage = (_options$pages$error = options === null || options === void 0 ? void 0 : (_options$pages2 = options.pages) === null || _options$pages2 === void 0 ? void 0 : _options$pages2.error) !== null && _options$pages$error !== void 0 ? _options$pages$error : "/api/auth/error";
  const basePath = (0, _parseUrl.default)(process.env.NEXTAUTH_URL).path;

  if (req.nextUrl.pathname.startsWith(basePath) || [signInPage, errorPage].includes(req.nextUrl.pathname)) {
    return;
  }

  const secret = (_options$secret = options === null || options === void 0 ? void 0 : options.secret) !== null && _options$secret !== void 0 ? _options$secret : process.env.NEXTAUTH_SECRET;

  if (!secret) {
    console.error(`[next-auth][error][NO_SECRET]`, `\nhttps://next-auth.js.org/errors#no_secret`);
    return {
      redirect: _server.NextResponse.redirect(`${errorPage}?error=Configuration`)
    };
  }

  const token = await (0, _jwt.getToken)({
    req: req,
    secret
  });
  const authorized = (_options$callbacks$au = options === null || options === void 0 ? void 0 : (_options$callbacks = options.callbacks) === null || _options$callbacks === void 0 ? void 0 : _options$callbacks.authorized) !== null && _options$callbacks$au !== void 0 ? _options$callbacks$au : ({
    token
  }) => !!token;
  const isAuthorized = await authorized({
    req,
    token
  });
  if (isAuthorized) return await (onSuccess === null || onSuccess === void 0 ? void 0 : onSuccess(token));
  return _server.NextResponse.redirect(`${signInPage}?${new URLSearchParams({
    callbackUrl: req.url
  })}`);
}

function withAuth(...args) {
  if (args[0] instanceof _server.NextRequest) {
    return handleMiddleware(...args);
  }

  if (typeof args[0] === "function") {
    const middleware = args[0];
    const options = args[1];
    return async (...args) => await handleMiddleware(args[0], options, async token => {
      ;
      args[0].token = token;
      return await middleware(...args);
    });
  }

  const options = args[0];
  return async (...args) => await handleMiddleware(args[0], options);
}

var _default = withAuth;
exports.default = _default;